<?php
/**
 * ヘルパークラス
 * @package     Site
 * @copyright   Copyright (C) 2011 MicroEngine Inc.
 */
class Site_Helper
{

    /**
     * モジュール読み込み
     * @param string $module_name
     */
    public function include_module($module_name)
    {
        // ファイル名のチェック
        if (!preg_match('/^[\w-.]+$/', $module_name)) {
            // a-zA-Z-9_-. 以外の文字があれば読み込まない
            return;
        }
        if (file_exists(DATA_ROOT . '/module/' . $module_name)) {
            include(DATA_ROOT . '/module/' . $module_name);
        }
    }

    /**
     * UserAgentを元に表示するキャッシュファイルのパスを返す
     * @param array $cache_list
     * @return string $cache_path
     */
    public function get_cache_path($cache_list)
    {
        $cache_path = '';

        // クッキー名取得
        $cookie_name = Me_Config::get_template('display_mode_cookie_name');

        // 表示テンプレート変更
        $display_mode = null;
        if (!empty($_POST) && isset($_POST[$cookie_name])) {
            if (isset($cache_list[$_POST[$cookie_name]])) {
                // キャッシュリストにある有効な名前の場合
                // クッキー有効期限取得
                $cookie_expire = Me_Config::get_template('display_mode_cookie_expire');
                setcookie($cookie_name, $_POST[$cookie_name], time() + 86400 * $cookie_expire, '/');
                $display_mode = $_POST[$cookie_name];
            } else if (strlen($_POST[$cookie_name]) === 0) {
                // 空文字が送られたら、そのクッキーを削除する。
                setcookie($cookie_name, '', time() - 42000, '/');
                unset($_COOKIE[$cookie_name]);
            } else {
                // パラメータはあるが、空文字でもなく有効な名前がない場合は、クッキーを確認
                // Cookieの確認
                if (strlen($_COOKIE[$cookie_name]) > 0) {
                    $display_mode = $_COOKIE[$cookie_name];
                }
            }
        } else {
            // パラメータがない場合は、Cookieの確認
            if (strlen($_COOKIE[$cookie_name]) > 0) {
                $display_mode = $_COOKIE[$cookie_name];
            }
        }

        if (strlen($display_mode) > 0 && isset($cache_list[$display_mode])) {
            $cache_path = DATA_ROOT . $cache_list[$display_mode];
            return $cache_path;
        }

        // browser.iniの取得
        $browser_ini_path = APP_ROOT . '/def/config/browser.ini';
        if (file_exists(DATA_ROOT . '/config/browser.ini')) {
            $browser_ini_path = DATA_ROOT . '/config/browser.ini';
        }
        $ini = parse_ini_file($browser_ini_path, true);

        // iniに指定したセクション順に評価する。
        foreach ($ini as $condition_name => $condition_list) {
            if (isset($cache_list[$condition_name])) {
                // name 指定の場合は、連結して単純に含まれるかどうかの正規表現を実行する。
                if (isset($condition_list['name'])) {
                    $pattern = '#' . implode('|', $condition_list['name']) . '#i';
                    if (preg_match($pattern, $_SERVER['HTTP_USER_AGENT'])) {
                        $cache_path = DATA_ROOT . $cache_list[$condition_name];
                        break;
                    }
                }
                // regex 指定の場合は、それぞれをpreg_matchの正規表現文字列として直接扱う。
                if (isset($condition_list['regex'])) {
                    foreach ($condition_list['regex'] as $pattern) {
                        if (preg_match($pattern, $_SERVER['HTTP_USER_AGENT'])) {
                            $cache_path = DATA_ROOT . $cache_list[$condition_name];
                            break;
                        }
                    }
                }
            }
        }
        // 一致するものがなければ、デフォルトのキャッシュファイルのパスをセット
        if (strlen($cache_path) == 0) {
            $cache_path = DATA_ROOT . $cache_list['_DEFAULT'];
        }
        return $cache_path;
    }
}